==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { WebGridBaseDirectiveDescription } from "./WebGridBaseDirectiveDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebGridDescription = /*@__PURE__*/ (() => {
    class WebGridDescription extends WebGridBaseDirectiveDescription {
        constructor() {
            super();
            this.hh = false;
            this.hv = null;
            this.ht = null;
            this.h0 = null;
            this.hb = null;
            this.hs = null;
            this.hp = null;
            this.hn = 0;
            this.ha = null;
            this.g9 = null;
            this.hi = false;
            this.hf = null;
            this.hu = null;
            this.hx = null;
            this.hz = null;
            this.hw = null;
            this.hj = false;
            this.hr = null;
            this.hy = null;
        }
        get_type() {
            return "WebGrid";
        }
        get groupsExpanded() {
            return this.hh;
        }
        set groupsExpanded(a) {
            this.hh = a;
            this.e("GroupsExpanded");
        }
        get dropAreaTemplateRef() {
            return this.hv;
        }
        set dropAreaTemplateRef(a) {
            this.hv = a;
            this.e("DropAreaTemplateRef");
        }
        get detailTemplateRef() {
            return this.ht;
        }
        set detailTemplateRef(a) {
            this.ht = a;
            this.e("DetailTemplateRef");
        }
        get id() {
            return this.h0;
        }
        set id(a) {
            this.h0 = a;
            this.e("Id");
        }
        get groupsRecords() {
            return this.hb;
        }
        set groupsRecords(a) {
            this.hb = a;
            this.e("GroupsRecords");
        }
        get dataRef() {
            return this.hs;
        }
        set dataRef(a) {
            this.hs = a;
            this.e("DataRef");
        }
        get filteredData() {
            return this.hp;
        }
        set filteredData(a) {
            this.hp = a;
            this.e("FilteredData");
        }
        get totalItemCount() {
            return this.hn;
        }
        set totalItemCount(a) {
            this.hn = a;
            this.e("TotalItemCount");
        }
        get groupingExpressions() {
            return this.ha;
        }
        set groupingExpressions(a) {
            this.ha = a;
            this.e("GroupingExpressions");
        }
        get groupingExpansionState() {
            return this.g9;
        }
        set groupingExpansionState(a) {
            this.g9 = a;
            this.e("GroupingExpansionState");
        }
        get hideGroupedColumns() {
            return this.hi;
        }
        set hideGroupedColumns(a) {
            this.hi = a;
            this.e("HideGroupedColumns");
        }
        get groupStrategy() {
            return this.hf;
        }
        set groupStrategy(a) {
            this.hf = a;
            this.e("GroupStrategy");
        }
        get dropAreaMessage() {
            return this.hu;
        }
        set dropAreaMessage(a) {
            this.hu = a;
            this.e("DropAreaMessage");
        }
        get groupByRowSelectorTemplateRef() {
            return this.hx;
        }
        set groupByRowSelectorTemplateRef(a) {
            this.hx = a;
            this.e("GroupByRowSelectorTemplateRef");
        }
        get groupRowTemplateRef() {
            return this.hz;
        }
        set groupRowTemplateRef(a) {
            this.hz = a;
            this.e("GroupRowTemplateRef");
        }
        get groupAreaTemplateRef() {
            return this.hw;
        }
        set groupAreaTemplateRef(a) {
            this.hw = a;
            this.e("GroupAreaTemplateRef");
        }
        get showGroupArea() {
            return this.hj;
        }
        set showGroupArea(a) {
            this.hj = a;
            this.e("ShowGroupArea");
        }
        get dataPreLoadRef() {
            return this.hr;
        }
        set dataPreLoadRef(a) {
            this.hr = a;
            this.e("DataPreLoadRef");
        }
        get groupingDoneRef() {
            return this.hy;
        }
        set groupingDoneRef(a) {
            this.hy = a;
            this.e("GroupingDoneRef");
        }
    }
    WebGridDescription.$t = /*@__PURE__*/ markType(WebGridDescription, 'WebGridDescription', WebGridBaseDirectiveDescription.$);
    return WebGridDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebGridDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { WebGridBaseDirectiveDescription } from "./WebGridBaseDirectiveDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebGridDescription = /*@__PURE__*/ (() => {
    class WebGridDescription extends WebGridBaseDirectiveDescription {
        get_type() {
            return "WebGrid";
        }
        constructor() {
            super();
            this.gv = false;
            this.g7 = null;
            this.g5 = null;
            this.hb = null;
            this.g4 = null;
            this.g1 = 0;
            this.gq = null;
            this.gp = null;
            this.gw = false;
            this.gt = null;
            this.g6 = null;
            this.g8 = null;
            this.ha = null;
            this.gx = false;
            this.g3 = null;
            this.g9 = null;
        }
        get groupsExpanded() {
            return this.gv;
        }
        set groupsExpanded(a) {
            this.gv = a;
            this.g("GroupsExpanded");
        }
        get dropAreaTemplateRef() {
            return this.g7;
        }
        set dropAreaTemplateRef(a) {
            this.g7 = a;
            this.g("DropAreaTemplateRef");
        }
        get detailTemplateRef() {
            return this.g5;
        }
        set detailTemplateRef(a) {
            this.g5 = a;
            this.g("DetailTemplateRef");
        }
        get id() {
            return this.hb;
        }
        set id(a) {
            this.hb = a;
            this.g("Id");
        }
        get dataRef() {
            return this.g4;
        }
        set dataRef(a) {
            this.g4 = a;
            this.g("DataRef");
        }
        get totalItemCount() {
            return this.g1;
        }
        set totalItemCount(a) {
            this.g1 = a;
            this.g("TotalItemCount");
        }
        get groupingExpressions() {
            return this.gq;
        }
        set groupingExpressions(a) {
            this.gq = a;
            this.g("GroupingExpressions");
        }
        get groupingExpansionState() {
            return this.gp;
        }
        set groupingExpansionState(a) {
            this.gp = a;
            this.g("GroupingExpansionState");
        }
        get hideGroupedColumns() {
            return this.gw;
        }
        set hideGroupedColumns(a) {
            this.gw = a;
            this.g("HideGroupedColumns");
        }
        get groupStrategy() {
            return this.gt;
        }
        set groupStrategy(a) {
            this.gt = a;
            this.g("GroupStrategy");
        }
        get dropAreaMessage() {
            return this.g6;
        }
        set dropAreaMessage(a) {
            this.g6 = a;
            this.g("DropAreaMessage");
        }
        get groupByRowSelectorTemplateRef() {
            return this.g8;
        }
        set groupByRowSelectorTemplateRef(a) {
            this.g8 = a;
            this.g("GroupByRowSelectorTemplateRef");
        }
        get groupRowTemplateRef() {
            return this.ha;
        }
        set groupRowTemplateRef(a) {
            this.ha = a;
            this.g("GroupRowTemplateRef");
        }
        get showGroupArea() {
            return this.gx;
        }
        set showGroupArea(a) {
            this.gx = a;
            this.g("ShowGroupArea");
        }
        get dataPreLoadRef() {
            return this.g3;
        }
        set dataPreLoadRef(a) {
            this.g3 = a;
            this.g("DataPreLoadRef");
        }
        get groupingDoneRef() {
            return this.g9;
        }
        set groupingDoneRef(a) {
            this.g9 = a;
            this.g("GroupingDoneRef");
        }
    }
    WebGridDescription.$t = /*@__PURE__*/ markType(WebGridDescription, 'WebGridDescription', WebGridBaseDirectiveDescription.$);
    return WebGridDescription;
})();
